@@ -7,13 +7,13 @@
 #include <R_ext/Rdynload.h>
 #include <ctype.h>
 
-#ifdef ENABLE_NLS
-#include <libintl.h>
-#define _(String) dgettext ("lotri", String)
-/* replace pkg as appropriate */
-#else
+/* #ifdef ENABLE_NLS */
+/* #include <libintl.h> */
+/* #define _(String) dgettext ("lotri", String) */
+/* /\* replace pkg as appropriate *\/ */
+/* #else */
 #define _(String) (String)
-#endif
+/* #endif */
 
 
 static inline int casecmp(const char *s1, const char *s2) {
